==> enlightenment-0.20.7-1-armv7h.pkg.tar.xz: usr/include/enlightenment/e_includes.h <==
#include "e_mmx.h"
#include "e_object.h"
#include "e_user.h"
#include "e_path.h"
#include "e_ipc.h"
#include "e_error.h"
#include "e_zone.h"
#include "e_desk.h"
#include "e_auth.h"
#include "e_randr2.h"
#ifndef HAVE_WAYLAND_ONLY
# include "e_comp_x.h"
#endif
#include "e_pixmap.h"
#include "e_comp_object.h"
#include "e_client.h"
#include "e_pointer.h"
#include "e_config.h"
#include "e_config_data.h"
#include "e_menu.h"
#include "e_icon.h"
#include "e_flowlayout.h"
#include "e_init.h"
#include "e_int_menus.h"
#include "e_module.h"
#include "e_focus.h"
#include "e_place.h"
#include "e_resist.h"
#include "e_startup.h"
#include "e_signals.h"
#include "e_xinerama.h"
#include "e_layout.h"
#include "e_font.h"
#include "e_intl.h"
#include "e_intl_data.h"
#include "e_theme.h"
#include "e_dnd.h"
#include "e_bindings.h"
#include "e_moveresize.h"
#include "e_actions.h"
#include "e_gadcon_popup.h"
#include "e_ipc_codec.h"
#include "e_test.h"
#include "e_prefix.h"
#include "e_datastore.h"
#include "e_msg.h"
#include "e_alert.h"
#include "e_maximize.h"
#include "e_grabinput.h"
#include "e_bg.h"
#include "e_remember.h"
#include "e_win.h"
#include "e_pan.h"
#include "e_zoomap.h"
#include "e_dialog.h"
#include "e_configure.h"
#include "e_about.h"
#include "e_theme_about.h"
#include "e_widget.h"
#include "e_widget_check.h"
#include "e_widget_radio.h"
#include "e_widget_framelist.h"
#include "e_widget_list.h"
#include "e_widget_button.h"
#include "e_widget_label.h"
#include "e_widget_frametable.h"
#include "e_widget_table.h"
#include "e_widget_entry.h"
#include "e_widget_image.h"
#include "e_config_dialog.h"
#include "e_int_client_locks.h"
#include "e_thumb.h"
#include "e_int_client_remember.h"
#include "e_desktop_editor.h"
#include "e_scrollframe.h"
#include "e_int_client_menu.h"
#include "e_ilist.h"
#include "e_livethumb.h"
#include "e_widget_ilist.h"
#include "e_widget_config_list.h"
#include "e_slider.h"
#include "e_widget_slider.h"
#include "e_desklock.h"
#include "e_screensaver.h"
#include "e_dpms.h"
#include "e_int_config_modules.h"
#include "e_exehist.h"
#include "e_widget_textblock.h"
#include "e_gadcon.h"
#include "e_shelf.h"
#include "e_widget_preview.h"
#include "e_int_shelf_config.h"
#include "e_int_gadcon_config.h"
#include "e_confirm_dialog.h"
#include "e_int_client_prop.h"
#include "e_entry_dialog.h"
#include "e_fm.h"
#include "e_fm_op_registry.h"
#include "e_widget_scrollframe.h"
#include "e_sha1.h"
#include "e_widget_framelist.h"
#include "e_widget_fsel.h"
#include "e_fm_mime.h"
#include "e_color.h"
#include "e_spectrum.h"
#include "e_widget_spectrum.h"
#include "e_widget_color_well.h"
#include "e_color_dialog.h"
#include "e_sys.h"
#include "e_obj_dialog.h"
#include "e_filereg.h"
#include "e_widget_aspect.h"
#include "e_widget_bgpreview.h"
#include "e_deskmirror.h"
#include "e_fm_prop.h"
#include "e_mouse.h"
#include "e_order.h"
#include "e_exec.h"
#include "e_widget_font_preview.h"
#include "e_fm_custom.h"
#include "e_msgbus.h"
#include "e_toolbar.h"
#include "e_int_toolbar_config.h"
#include "e_powersave.h"
#include "e_slidesel.h"
#include "e_slidecore.h"
#include "e_widget_flist.h"
#include "e_fm_op.h"
#include "e_scale.h"
#include "e_widget_toolbar.h"
#include "e_widget_toolbook.h"
#include "e_acpi.h"
#include "e_env.h"
#include "e_backlight.h"
#include "e_deskenv.h"
#include "e_xsettings.h"
#include "e_update.h"
#include "e_xkb.h"
#include "e_log.h"
#include "e_import_dialog.h"
#include "e_import_config_dialog.h"
#include "e_grab_dialog.h"
#include "e_widget_filepreview.h"
#include "e_dbusmenu.h"
#include "e_notification.h"
#include "e_comp.h"
#include "e_comp_cfdata.h"
#include "e_comp_canvas.h"
#include "e_utils.h"
#include "e_hints.h"
#include "e_comp_x_randr.h"

#ifdef HAVE_WAYLAND
# include "e_comp_wl.h"
# include "e_comp_wl_data.h"
# include "e_comp_wl_input.h"
# include "e_uuid_store.h"
#endif

==> enlightenment-0.21.2-1-armv7h.pkg.tar.xz: usr/include/enlightenment/e_includes.h <==
#include "e_mmx.h"
#include "e_object.h"
#include "e_user.h"
#include "e_path.h"
#include "e_ipc.h"
#include "e_error.h"
#include "e_zone.h"
#include "e_desk.h"
#include "e_auth.h"
#include "e_randr2.h"
#ifndef HAVE_WAYLAND_ONLY
# include "e_comp_x.h"
#endif
#include "e_pixmap.h"
#include "e_comp_object.h"
#include "e_client.h"
#include "e_pointer.h"
#include "e_config.h"
#include "e_config_data.h"
#include "e_menu.h"
#include "e_icon.h"
#include "e_flowlayout.h"
#include "e_init.h"
#include "e_int_menus.h"
#include "e_module.h"
#include "e_focus.h"
#include "e_place.h"
#include "e_resist.h"
#include "e_startup.h"
#include "e_signals.h"
#include "e_xinerama.h"
#include "e_layout.h"
#include "e_font.h"
#include "e_intl.h"
#include "e_intl_data.h"
#include "e_theme.h"
#include "e_dnd.h"
#include "e_bindings.h"
#include "e_moveresize.h"
#include "e_actions.h"
#include "e_gadcon_popup.h"
#include "e_ipc_codec.h"
#include "e_test.h"
#include "e_prefix.h"
#include "e_datastore.h"
#include "e_msg.h"
#include "e_alert.h"
#include "e_maximize.h"
#include "e_grabinput.h"
#include "e_bg.h"
#include "e_remember.h"
#include "e_win.h"
#include "e_pan.h"
#include "e_zoomap.h"
#include "e_dialog.h"
#include "e_configure.h"
#include "e_about.h"
#include "e_theme_about.h"
#include "e_video.h"
#include "e_widget.h"
#include "e_widget_check.h"
#include "e_widget_radio.h"
#include "e_widget_framelist.h"
#include "e_widget_list.h"
#include "e_widget_button.h"
#include "e_widget_label.h"
#include "e_widget_frametable.h"
#include "e_widget_table.h"
#include "e_widget_entry.h"
#include "e_widget_image.h"
#include "e_config_dialog.h"
#include "e_int_client_locks.h"
#include "e_thumb.h"
#include "e_int_client_remember.h"
#include "e_desktop_editor.h"
#include "e_scrollframe.h"
#include "e_int_client_menu.h"
#include "e_ilist.h"
#include "e_livethumb.h"
#include "e_widget_ilist.h"
#include "e_widget_config_list.h"
#include "e_slider.h"
#include "e_widget_slider.h"
#include "e_desklock.h"
#include "e_screensaver.h"
#include "e_dpms.h"
#include "e_int_config_modules.h"
#include "e_exehist.h"
#include "e_widget_textblock.h"
#include "e_gadcon.h"
#include "e_shelf.h"
#include "e_widget_preview.h"
#include "e_int_shelf_config.h"
#include "e_int_gadcon_config.h"
#include "e_confirm_dialog.h"
#include "e_int_client_prop.h"
#include "e_entry_dialog.h"
#include "e_fm.h"
#include "e_fm_op_registry.h"
#include "e_widget_scrollframe.h"
#include "e_sha1.h"
#include "e_widget_framelist.h"
#include "e_widget_fsel.h"
#include "e_fm_mime.h"
#include "e_color.h"
#include "e_spectrum.h"
#include "e_widget_spectrum.h"
#include "e_widget_color_well.h"
#include "e_color_dialog.h"
#include "e_sys.h"
#include "e_obj_dialog.h"
#include "e_filereg.h"
#include "e_widget_aspect.h"
#include "e_widget_bgpreview.h"
#include "e_deskmirror.h"
#include "e_fm_prop.h"
#include "e_mouse.h"
#include "e_order.h"
#include "e_exec.h"
#include "e_widget_font_preview.h"
#include "e_fm_custom.h"
#include "e_msgbus.h"
#include "e_toolbar.h"
#include "e_int_toolbar_config.h"
#include "e_powersave.h"
#include "e_slidesel.h"
#include "e_slidecore.h"
#include "e_widget_flist.h"
#include "e_fm_op.h"
#include "e_scale.h"
#include "e_widget_toolbar.h"
#include "e_widget_toolbook.h"
#include "e_acpi.h"
#include "e_env.h"
#include "e_backlight.h"
#include "e_deskenv.h"
#include "e_xsettings.h"
#include "e_update.h"
#include "e_xkb.h"
#include "e_log.h"
#include "e_import_dialog.h"
#include "e_import_config_dialog.h"
#include "e_grab_dialog.h"
#include "e_widget_filepreview.h"
#include "e_dbusmenu.h"
#include "e_notification.h"
#include "e_comp.h"
#include "e_comp_cfdata.h"
#include "e_comp_canvas.h"
#include "e_utils.h"
#include "e_hints.h"
#include "e_comp_x_randr.h"
#include "e_gadget.h"
#include "e_bryce.h"

#ifdef HAVE_WAYLAND
# include "e_comp_wl.h"
# include "e_comp_wl_data.h"
# include "e_comp_wl_dmabuf.h"
# include "e_comp_wl_input.h"
#endif
